@@ -1,6 +1,6 @@
 from .ATCVectorizer import ATCVectorizer
 from .Gref94Vectorizer import Gref94Vectorizer
 from .LTUVectorizer import LTUVectorizer
-from ObservedExpected import ObservedExpectedVectorizer
+from .ObservedExpected import ObservedExpectedVectorizer
 from .TtestVectorizer import TtestVectorizer
 from .Tficf import TficfVectorizer
